<?php

global $details_text;
$details_text = array (

'task'                =>    'Task',
'edittask'            =>    'Edit this task',
'openedby'            =>    'Opened by',
'editedby'            =>    'Last edited by',
'tasktype'            =>    'Task Type',
'category'            =>    'Category',
'status'              =>    'Status',
'assignedto'          =>    'Assigned To',
'noone'               =>    'No-one',
'operatingsystem'     =>    'Operating System',
'severity'            =>    'Severity',
'reportedversion'     =>    'Reported Version',
'dueinversion'        =>    'Due in Version',
'undecided'           =>    'Undecided',
'percentcomplete'     =>    'Percent Complete',
'details'             =>    'Details',
'savedetails'         =>    'Save Details',
'canceledit'          =>    'Cancel Edit',
'anonymous'           =>    'Anonymous Submitter',
'complete'            =>    'complete',
'closedby'            =>    'Closed by',
'reasonforclosing'    =>    'Reason for closing:',
'reopenthistask'      =>    'Re-open this task',
'closetask'           =>    'Close Task',
'comments'            =>    'Comments',
'attachments'         =>    'Attachments',
'relatedtasks'        =>    'Related Tasks',
'notifications'       =>    'Notifications',
'edit'                =>    'Edit',
'delete'              =>    'Delete',
'commentby'           =>    'Comment by',
'addcomment'          =>    'Add comment',
'fileuploadedby'      =>    'File uploaded by',
'uploadafile'         =>    'Attach a file',             // Changed in version 0.9.8
'description'         =>    'Description',
'uploadnow'           =>    'Upload now!',
'thesearerelated'     =>    'These tasks are related to this task',
'remove'              =>    'Remove',
'addnewrelated'       =>    'Add a new related task',
'add'                 =>    'Add!',
'otherrelated'        =>    'Other tasks that this task is related to',
'receivenotify'       =>    'These users will receive detailed notifications when this task changes.',
'addusertolist'       =>    'Add user to this list',
'addtolist'           =>    'Add to list',
'addmyself'           =>    'Add myself to this list',
'removemyself'        =>    'Remove myself from this list',
//'invalidtaskid'       =>    'There is no task with that id!',  Removed in 0.9.7
'theseusersnotify'    =>    'These users will receive detailed notifications whenever this task changes.',

// Added in version 0.9.5

'attachedtoproject'   =>    'Attached to Project',

// Added in version 0.9.6

'reminders'           =>   'Reminders',
'system'              =>   'System',
'remindthisuser'      =>   'Remind this user',
'thisoften'           =>   'This often',
'startafter'          =>   'Wait before starting reminders',
'hours'               =>   'Hour(s)',
'days'                =>   'Day(s)',
'weeks'               =>   'Week(s)',
'addreminder'         =>   'Add Reminder',
'defaultreminder'     =>   'This is a reminder to look at the following Flyspray task:',
'message'             =>   'Message',
'closed'              =>   'Closed',
'filename'            =>   'Filename:',
'date'                =>   'Date:',
'filesize'            =>   'File Size:',
'closurecomment'      =>   'Additional comments about closing:',
'history'             =>   'History',
'nohistory'           =>   'No history available.',
'eventdate'           =>   'Date',
'user'                =>   'User',
'event'               =>   'Event',
'fieldchanged'        =>   'Field changed',
'taskopened'          =>   'Task opened',
'taskreopened'        =>   'Task re-opened',
'taskclosed'          =>   'Task closed',
'commentadded'        =>   'Comment added',
'commentedited'       =>   'Comment edited',
'commentdeleted'      =>   'Comment deleted',
'attachmentadded'     =>   'Attachment added',
'attachmentdeleted'   =>   'Attachment deleted',
'taskedited'          =>   'Task details edited',
'notificationadded'   =>   'User added to notification list',
'notificationdeleted' => 'User removed from notification list',
'relatedadded'        =>   'Related task added',
'relateddeleted'      =>   'Related task removed',
'taskassigned'        =>   'Task assigned to',
'taskreassigned'      =>   'Task reassigned to',
'assignmentremoved'   =>   'Assignment removed',
'summary'             =>   'Summary',
'addedasrelated'      =>   'Task added to the related list of',
'deletedasrelated'    =>   'Task removed from the related list of',
'reminderadded'       =>   'Reminder added',
'reminderdeleted'     =>   'Reminder removed',
'priority'            =>   'Priority',
'previousvalue'       =>   'Previous value',
'newvalue'            =>   'New value',


// Added in version 0.9.7

'selectareason'         =>    'Select a reason',
'assigntome'            =>    'Assign to me',
'reopenrequest'         =>    'Request re-open',
'requestclose'          =>    'Request closure',
'ownershiptaken'        =>    'User took ownership',
'closerequestmade'      =>    'Requested task closure',
'reopenrequestmade'     =>    'Requested task be re-opened',
'taskdependson'         =>    'This task depends upon',
'taskblocks'            =>    'This task blocks these from closing',
'addnew'                =>    'Add new',
'depadded'              =>    'Dependency added:',
'depaddedother'         =>    'This task added as dependency:',
'depremoved'            =>    'Dependency removed:',
'depremovedother'       =>    'This task removed from other task\'s dependency list:',
'showdetailserror'      =>    'That task does not exist, or you don\'t have permission to view it.',
'makeprivate'           =>    'Make Private',
'makepublic'            =>    'Make Public',
'taskmadeprivate'       =>    'Task made private',
'taskmadepublic'        =>    'Privacy removed - task made public',


// Added in version 0.9.8

'confirmdeletecomment'  =>    'Really delete this comment?  All attachments will also be deleted!',
'confirmdeleteattach'   =>    'Really delete this attachment?',
'selectedhistory'       =>    'Showing selected history details',
'showallhistory'        =>    'Show full history tab again',
'hidethis'              =>    'Hide this area again',
'mark100'               =>    'Mark task 100% complete',
'watchtask'             =>    'Watch this task',
'stopwatching'          =>    'Stop watching this task',
'commentlink'           =>    'Link to this comment',
'submitreq'             =>    'Submit request',
'givereason'            =>    'Reason for this request',
'pmreqdenied'           =>    'Project Manager denied request',
'taskpendingreq'        =>    'Project Manager action pending.  See the History tab for details.',
'previoustask'          =>    'Previous task',
'nexttask'              =>    'Next task',
'duedate'               =>    'Due Date',
'selectmorefiles'       =>    'Select more files',
'attachnoperms'         =>    'There are attachments with this comment, but you have no permission to view them.',
'open'                  =>    'OPEN',
'closed'                =>    'CLOSED',
'depgraph'              =>    'View Dependency Graph',
'reset'                 =>    'Reset',

);
?>
